@@ -2,8 +2,8 @@ import requests
 from datomizer.utils import constants
 
 
-def get_domain_by_username(username: str) -> str:
-    response = requests.get(constants.ONBOARDING_GET_USER_DOMAIN_DEFAULT % username)
+def get_domain_by_username(username: str, env: str = 'app') -> str:
+    response = requests.get(constants.ONBOARDING_GET_USER_DOMAIN_DEFAULT % (env, username))
     return response.url.replace("https://", "").split('/')[0]
 
 
