@@ -45,6 +45,6 @@ def upload_dataframe(presigned_url: str, df, name: str) -> None:
 
 
 def upload_temp_file(path, presigned_url):
-    with open(path, 'r', encoding='utf-8') as temp_file:
+    with open(path, 'rb') as temp_file:
         response = requests.put(url=presigned_url, data=temp_file)
         Datomizer.validate_response(response, "Upload to put presigned url")
