@@ -1,6 +1,5 @@
-ENV_SUBDOMAIN = "app"
 URL = "https://%s"
-DEFAULT_DOMAIN = ENV_SUBDOMAIN + ".datomize.com"
+DEFAULT_DOMAIN = "%s.datomize.com"
 
 MANAGEMENT = "/api"
 ONBOARDING = "/onboarding"
